@@ -39,7 +39,7 @@ static char *peek3 (char *, char *);	/* peek into internals */
 static int peekfile (int);	/* read a byte from stream */
 static char *do_system (char *);	/* executes command via command.com */
 static int do_system2 (char *);	/* execute command as system */
-
+static double myrand (); /* generate random number in given range */
 
 /* ------------- global variables ---------------- */
 
@@ -506,11 +506,11 @@ function (struct command *current)	/* performs a function */
         result = stNUMBER;
         break;
     case fRAN:
-        value = a1->value * (((double) rand ()) / (((double) RAND_MAX) + 1));
+        value = a1->value * myrand ();
         result = stNUMBER;
         break;
     case fRAN2:
-        value = (double) rand () / RAND_MAX;
+        value = myrand ();
         result = stNUMBER;
         break;
     case fMIN:
@@ -895,6 +895,17 @@ do_system2 (char *cmd)		/* hand over execution of command to system */
 }
 
 
+static double
+myrand ()
+{
+    long ran;
+	
+    ran = (((long) rand ()) & 0x7fffL) << 15 | ((long) rand () & 0x7fffL);
+
+    return ((double) ran) / ((double) 0x3fffffffL);
+}
+
+
 static void
 clear_buff ()			/* clear system-input buffers */
 {
